Struct ioe::IoError [−][src]
pub struct IoError { /* fields omitted */ }Trait Implementations
impl Clone for IoError[src]
impl Clone for IoErrorfn clone(&self) -> IoError[src]
fn clone(&self) -> IoErrorReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for IoError[src]
impl Debug for IoErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for IoError[src]
impl PartialEq for IoErrorfn eq(&self, other: &IoError) -> bool[src]
fn eq(&self, other: &IoError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &IoError) -> bool[src]
fn ne(&self, other: &IoError) -> boolThis method tests for !=.
impl Eq for IoError[src]
impl Eq for IoErrorimpl PartialOrd for IoError[src]
impl PartialOrd for IoErrorfn partial_cmp(&self, other: &IoError) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &IoError) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &IoError) -> bool[src]
fn lt(&self, other: &IoError) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &IoError) -> bool[src]
fn le(&self, other: &IoError) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &IoError) -> bool[src]
fn gt(&self, other: &IoError) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &IoError) -> bool[src]
fn ge(&self, other: &IoError) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl Ord for IoError[src]
impl Ord for IoErrorfn cmp(&self, other: &IoError) -> Ordering[src]
fn cmp(&self, other: &IoError) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl From<Error> for IoError[src]
impl From<Error> for IoError